=======
History
=======

0.3.0 (2021-04-24)
------------------

* Make it possible to pass a custom normalization function (Terence D. Honles)
* Fix regular expression to require RSS (Terence D. Honles)
* Use Github actions instead of Travis (Terence D. Honles)

0.2.0 (2020-01-10)
------------------

* Count and show occurrences and per call leak count.

0.1.0 (2019-04-12)
------------------

* First release on PyPI.
